branch: elpa/llama
commit 1463ec95df4cfcd655ca9cf4549c86d6df28d791
Author: Jonas Bernoulli <jo...@bernoul.li>
Commit: Jonas Bernoulli <jo...@bernoul.li>

    Reword documentation to avoid `%' being linkified in docstring
    
    Suggested-by: L. Andrew <fland...@tutanota.com>
---
 README.org |  5 +++--
 llama.el   | 10 ++++++----
 2 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/README.org b/README.org
index c9eec02220..7a64a68767 100644
--- a/README.org
+++ b/README.org
@@ -20,8 +20,9 @@ following an optional argument have to be optional as well, 
thus
 their names have to begin with ~&~.  Symbol ~&*~ specifies extra
 (~&rest~) arguments.
 
-Instead of ~%1~, the shorthand ~%~ can be used, and using both ~%1~
-and ~%~ is not allowed.  Likewise ~&~ can be substituted for ~&1~.
+The shorter symbol ~%~ can be used instead of ~%1~, but using both
+in the same expression is not allowed.  Likewise ~&~ can be used
+instead of ~&1~.
 
 Instead of:
 
diff --git a/llama.el b/llama.el
index 1acc65b27b..a265db47c6 100644
--- a/llama.el
+++ b/llama.el
@@ -45,8 +45,9 @@
 ;; their names have to begin with `&'.  Symbol `&*' specifies extra
 ;; (`&rest') arguments.
 
 ;; Instead of `%1', the shorthand `%' can be used, and using both `%1'
 ;; and `%' is not allowed.  Likewise `&' can be substituted for `&1'.
 
 ;; Instead of:
 ;;
@@ -97,8 +98,9 @@ following an optional argument have to be optional as well, 
thus
 their names have to begin with `&'.  Symbol `&*' specifies extra
 \(`&rest') arguments.
 
-Instead of `%1', the shorthand `%' can be used, and using both `%1'
-and `%' is not allowed.  Likewise `&' can be substituted for `&1'.
+The shorter symbol `%' can be used instead of `%1', but using both
+in the same expression is not allowed.  Likewise `&' can be used
+instead of `&1'.
 
 Instead of:
 
@@ -45,8 +45,9 @@
 ;; (`&rest') arguments.
 
-;; Instead of `%1', the shorthand `%' can be used, and using both `%1'
-;; and `%' is not allowed.  Likewise `&' can be substituted for `&1'.
+;; The shorter symbol `%' can be used instead of `%1', but using both
+;; in the same expression is not allowed.  Likewise `&' can be used
+;; instead of `&1'.
 
 ;; Instead of:

Reply via email to